@@ -1,7 +1,7 @@
-from .borg_thread import BorgThread
+from .borg_job import BorgJob
 
 
-class BorgCheckThread(BorgThread):
+class BorgCheckJob(BorgJob):
 
     def started_event(self):
         self.app.backup_started_event.emit()
@@ -10,6 +10,7 @@ class BorgCheckThread(BorgThread):
     def finished_event(self, result):
         self.app.backup_finished_event.emit(result)
         self.result.emit(result)
+        self.app.backup_progress_event.emit(self.tr('Check completed.'))
 
     @classmethod
     def prepare(cls, profile):
