@@ -8,15 +8,16 @@ import json
 import os
 import sys
 from datetime import datetime, timedelta
-from dateutil.relativedelta import relativedelta as rd
 
 import peewee as pw
+from playhouse import signals
 from playhouse.migrate import SqliteMigrator, migrate
 
+from vorta.autostart import open_app_at_startup
 from vorta.i18n import trans_late
 from vorta.utils import slugify
 
-SCHEMA_VERSION = 17
+SCHEMA_VERSION = 18
 
 db = pw.Proxy()
 
@@ -37,7 +38,11 @@ class JSONField(pw.TextField):
         return value if value is None else json.loads(value)
 
 
-class RepoModel(pw.Model):
+class BaseModel(signals.Model):
+    """Common model superclass."""
+
+
+class RepoModel(BaseModel):
     """A single remote repo with unique URL."""
     url = pw.CharField(unique=True)
     added_at = pw.DateTimeField(default=datetime.now)
@@ -56,7 +61,7 @@ class RepoModel(pw.Model):
         database = db
 
 
-class RepoPassword(pw.Model):
+class RepoPassword(BaseModel):
     """Fallback to save repo passwords. Only used if no Keyring available."""
     url = pw.CharField(unique=True)
     password = pw.CharField()
@@ -65,7 +70,7 @@ class RepoPassword(pw.Model):
         database = db
 
 
-class BackupProfileModel(pw.Model):
+class BackupProfileModel(BaseModel):
     """Allows the user to switch between different configurations."""
     name = pw.CharField()
     added_at = pw.DateTimeField(default=datetime.now)
@@ -75,10 +80,13 @@ class BackupProfileModel(pw.Model):
     exclude_patterns = pw.TextField(null=True)
     exclude_if_present = pw.TextField(null=True)
     schedule_mode = pw.CharField(default='off')
-    schedule_interval_hours = pw.IntegerField(default=3)
-    schedule_interval_minutes = pw.IntegerField(default=42)
+    schedule_interval_count = pw.IntegerField(default=3)
+    schedule_interval_unit = pw.CharField(default='hours')
     schedule_fixed_hour = pw.IntegerField(default=3)
     schedule_fixed_minute = pw.IntegerField(default=42)
+    schedule_interval_hours = pw.IntegerField(default=3)  # no longer used
+    schedule_interval_minutes = pw.IntegerField(default=42)  # no longer used
+    schedule_make_up_missed = pw.BooleanField(default=True)
     validation_on = pw.BooleanField(default=True)
     validation_weeks = pw.IntegerField(default=3)
     prune_on = pw.BooleanField(default=False)
@@ -104,7 +112,7 @@ class BackupProfileModel(pw.Model):
         database = db
 
 
-class SourceFileModel(pw.Model):
+class SourceFileModel(BaseModel):
     """A folder to be backed up, related to a Backup Configuration."""
     dir = pw.CharField()
     dir_size = pw.BigIntegerField(default=-1)
@@ -118,7 +126,7 @@ class SourceFileModel(pw.Model):
         table_name = 'sourcedirmodel'
 
 
-class ArchiveModel(pw.Model):
+class ArchiveModel(BaseModel):
     """An archive in a remote repository."""
     snapshot_id = pw.CharField()
     name = pw.CharField()
@@ -134,7 +142,7 @@ class ArchiveModel(pw.Model):
         database = db
 
 
-class WifiSettingModel(pw.Model):
+class WifiSettingModel(BaseModel):
     """Save Wifi Settings"""
     ssid = pw.CharField()
     last_connected = pw.DateTimeField(null=True)
@@ -145,9 +153,10 @@ class WifiSettingModel(pw.Model):
         database = db
 
 
-class EventLogModel(pw.Model):
+class EventLogModel(BaseModel):
     """Keep a log of background jobs."""
     start_time = pw.DateTimeField(default=datetime.now)
+    end_time = pw.DateTimeField(default=datetime.now)
     category = pw.CharField()
     subcommand = pw.CharField(null=True)
     message = pw.CharField(null=True)
@@ -160,7 +169,7 @@ class EventLogModel(pw.Model):
         database = db
 
 
-class SchemaVersion(pw.Model):
+class SchemaVersion(BaseModel):
     """Keep DB version to apply the correct migrations."""
     version = pw.IntegerField()
     changed_at = pw.DateTimeField(default=datetime.now)
@@ -169,7 +178,7 @@ class SchemaVersion(pw.Model):
         database = db
 
 
-class SettingsModel(pw.Model):
+class SettingsModel(BaseModel):
     """App settings unrelated to a single profile or repo"""
     key = pw.CharField(unique=True)
     value = pw.BooleanField(default=False)
@@ -276,6 +285,12 @@ def get_misc_settings():
     return settings
 
 
+@signals.post_save(sender=SettingsModel)
+def setup_autostart(model_class, instance, created):
+    if instance.key == 'autostart':
+        open_app_at_startup(instance.value)
+
+
 def cleanup_db():
     # Clean up database
     db.execute_sql("VACUUM")
@@ -414,6 +429,19 @@ def init_db(con=None):
                                 'create_backup_cmd', pw.CharField(default=''))
         )
 
+    if current_schema.version < 18:
+        _apply_schema_update(
+            current_schema, 18,
+            migrator.add_column(BackupProfileModel._meta.table_name,
+                                'schedule_interval_unit', pw.CharField(default='hours')),
+            migrator.add_column(BackupProfileModel._meta.table_name,
+                                'schedule_interval_count', pw.IntegerField(default=3)),
+            migrator.add_column(BackupProfileModel._meta.table_name,
+                                'schedule_make_up_missed', pw.BooleanField(default=False)),
+            migrator.add_column(EventLogModel._meta.table_name,
+                                'end_time', pw.DateTimeField(default=datetime.now))
+        )
+
     # Create missing settings and update labels. Leave setting values untouched.
     for setting in get_misc_settings():
         s, created = SettingsModel.get_or_create(key=setting['key'], defaults=setting)
@@ -421,5 +449,5 @@ def init_db(con=None):
         s.save()
 
     # Delete old log entries after 3 months.
-    three_months_ago = datetime.now() - rd(months=3)
+    three_months_ago = datetime.now() - timedelta(days=3)
     EventLogModel.delete().where(EventLogModel.start_time < three_months_ago).execute()
