@@ -6,19 +6,19 @@ from PyQt5 import QtCore, uic
 from PyQt5.QtGui import QDesktopServices
 from PyQt5.QtWidgets import (QHeaderView, QMessageBox, QTableView,
                              QTableWidgetItem, QInputDialog, QMenu,
-                             QToolButton)
+                             QToolButton, QApplication)
 
-from vorta.borg.check import BorgCheckThread
-from vorta.borg.delete import BorgDeleteThread
-from vorta.borg.diff import BorgDiffThread
-from vorta.borg.extract import BorgExtractThread
-from vorta.borg.list_archive import BorgListArchiveThread
-from vorta.borg.list_repo import BorgListRepoThread
-from vorta.borg.info_archive import BorgInfoArchiveThread
-from vorta.borg.mount import BorgMountThread
-from vorta.borg.prune import BorgPruneThread
-from vorta.borg.umount import BorgUmountThread
-from vorta.borg.rename import BorgRenameThread
+from vorta.borg.check import BorgCheckJob
+from vorta.borg.delete import BorgDeleteJob
+from vorta.borg.diff import BorgDiffJob
+from vorta.borg.extract import BorgExtractJob
+from vorta.borg.list_archive import BorgListArchiveJob
+from vorta.borg.list_repo import BorgListRepoJob
+from vorta.borg.info_archive import BorgInfoArchiveJob
+from vorta.borg.mount import BorgMountJob
+from vorta.borg.prune import BorgPruneJob
+from vorta.borg.umount import BorgUmountJob
+from vorta.borg.rename import BorgRenameJob
 from vorta.i18n import trans_late
 from vorta.models import ArchiveModel, BackupProfileMixin
 from vorta.utils import (choose_file_dialog, format_archive_name, get_asset,
@@ -203,7 +203,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             self.prunePrefixPreview.setText(preview)
 
     def check_action(self):
-        params = BorgCheckThread.prepare(self.profile())
+        params = BorgCheckJob.prepare(self.profile())
         if not params['ok']:
             self._set_status(params['message'])
             return
@@ -216,24 +216,24 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 archive_name = archive_cell.text()
                 params['cmd'][-1] += f'::{archive_name}'
 
-        thread = BorgCheckThread(params['cmd'], params, parent=self.app)
-        thread.updated.connect(self._set_status)
-        thread.result.connect(self.check_result)
+        job = BorgCheckJob(params['cmd'], params, self.profile().repo.id)
+        job.updated.connect(self._set_status)
+        job.result.connect(self.check_result)
         self._toggle_all_buttons(False)
-        thread.start()
+        QApplication.instance().scheduler.jobs_manager.add_job(job)
 
     def check_result(self, result):
         if result['returncode'] == 0:
             self._toggle_all_buttons(True)
 
     def prune_action(self):
-        params = BorgPruneThread.prepare(self.profile())
+        params = BorgPruneJob.prepare(self.profile())
         if params['ok']:
-            thread = BorgPruneThread(params['cmd'], params, parent=self.app)
-            thread.updated.connect(self._set_status)
-            thread.result.connect(self.prune_result)
+            job = BorgPruneJob(params['cmd'], params, self.profile().repo.id)
+            job.updated.connect(self._set_status)
+            job.result.connect(self.prune_result)
             self._toggle_all_buttons(False)
-            thread.start()
+            QApplication.instance().scheduler.jobs_manager.add_job(job)
         else:
             self._set_status(params['message'])
 
@@ -245,13 +245,13 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             self._toggle_all_buttons(True)
 
     def list_action(self):
-        params = BorgListRepoThread.prepare(self.profile())
+        params = BorgListRepoJob.prepare(self.profile())
         if params['ok']:
-            thread = BorgListRepoThread(params['cmd'], params, parent=self.app)
-            thread.updated.connect(self._set_status)
-            thread.result.connect(self.list_result)
+            job = BorgListRepoJob(params['cmd'], params, self.profile().repo.id)
+            job.updated.connect(self._set_status)
+            job.result.connect(self.list_result)
             self._toggle_all_buttons(False)
-            thread.start()
+            QApplication.instance().scheduler.jobs_manager.add_job(job)
         else:
             self._set_status(params['message'])
 
@@ -264,13 +264,13 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
     def refresh_archive_action(self):
         archive_name = self.selected_archive_name()
         if archive_name is not None:
-            params = BorgInfoArchiveThread.prepare(self.profile(), archive_name)
+            params = BorgInfoArchiveJob.prepare(self.profile(), archive_name)
             if params['ok']:
-                thread = BorgInfoArchiveThread(params['cmd'], params, parent=self.app)
-                thread.updated.connect(self._set_status)
-                thread.result.connect(self.refresh_archive_result)
+                job = BorgInfoArchiveJob(params['cmd'], params, self.profile().repo.id)
+                job.updated.connect(self._set_status)
+                job.result.connect(self.refresh_archive_result)
                 self._toggle_all_buttons(False)
-                thread.start()
+                QApplication.instance().scheduler.jobs_manager.add_job(job)
 
     def refresh_archive_result(self, result):
         self._toggle_all_buttons(True)
@@ -288,7 +288,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
     def mount_action(self):
         profile = self.profile()
-        params = BorgMountThread.prepare(profile)
+        params = BorgMountJob.prepare(profile)
         if not params['ok']:
             self._set_status(params['message'])
             return
@@ -307,10 +307,10 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                     self.mount_points[params['current_archive']] = mount_point[0]
                 if params['ok']:
                     self._toggle_all_buttons(False)
-                    thread = BorgMountThread(params['cmd'], params, parent=self.app)
-                    thread.updated.connect(self.mountErrors.setText)
-                    thread.result.connect(self.mount_result)
-                    thread.start()
+                    job = BorgMountJob(params['cmd'], params, self.profile().repo.id)
+                    job.updated.connect(self.mountErrors.setText)
+                    job.result.connect(self.mount_result)
+                    QApplication.instance().scheduler.jobs_manager.add_job(job)
 
         dialog = choose_file_dialog(self, self.tr("Choose Mount Point"), want_folder=True)
         dialog.open(receive)
@@ -331,7 +331,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
         if mount_point is not None:
             profile = self.profile()
-            params = BorgUmountThread.prepare(profile)
+            params = BorgUmountJob.prepare(profile)
             if not params['ok']:
                 self._set_status(params['message'])
                 return
@@ -340,10 +340,10 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
             if os.path.normpath(mount_point) in params['active_mount_points']:
                 params['cmd'].append(mount_point)
-                thread = BorgUmountThread(params['cmd'], params, parent=self.app)
-                thread.updated.connect(self.mountErrors.setText)
-                thread.result.connect(self.umount_result)
-                thread.start()
+                job = BorgUmountJob(params['cmd'], params, self.profile().repo.id)
+                job.updated.connect(self.mountErrors.setText)
+                job.result.connect(self.umount_result)
+                QApplication.instance().scheduler.jobs_manager.add_job(job)
             else:
                 self._set_status(self.tr('Mount point not active.'))
                 return
@@ -376,7 +376,7 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             archive_cell = self.archiveTable.item(row_selected[0].row(), 4)
             if archive_cell:
                 archive_name = archive_cell.text()
-                params = BorgListArchiveThread.prepare(profile, archive_name)
+                params = BorgListArchiveJob.prepare(profile, archive_name)
 
                 if not params['ok']:
                     self._set_status(params['message'])
@@ -384,10 +384,11 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 self._set_status('')
                 self._toggle_all_buttons(False)
 
-                thread = BorgListArchiveThread(params['cmd'], params, parent=self.app)
-                thread.updated.connect(self.mountErrors.setText)
-                thread.result.connect(self.list_archive_result)
-                thread.start()
+                job = BorgListArchiveJob(params['cmd'], params, self.profile().repo.id)
+                job.updated.connect(self.mountErrors.setText)
+                job.result.connect(self.list_archive_result)
+                QApplication.instance().scheduler.jobs_manager.add_job(job)
+                return job
         else:
             self._set_status(self.tr('Select an archive to restore first.'))
 
@@ -398,14 +399,14 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 def receive():
                     extraction_folder = dialog.selectedFiles()
                     if extraction_folder:
-                        params = BorgExtractThread.prepare(
+                        params = BorgExtractJob.prepare(
                             self.profile(), archive.name, window.selected, extraction_folder[0])
                         if params['ok']:
                             self._toggle_all_buttons(False)
-                            thread = BorgExtractThread(params['cmd'], params, parent=self.app)
-                            thread.updated.connect(self.mountErrors.setText)
-                            thread.result.connect(self.extract_archive_result)
-                            thread.start()
+                            job = BorgExtractJob(params['cmd'], params, self.profile().repo.id)
+                            job.updated.connect(self.mountErrors.setText)
+                            job.result.connect(self.extract_archive_result)
+                            QApplication.instance().scheduler.jobs_manager.add_job(job)
                         else:
                             self._set_status(params['message'])
 
@@ -450,7 +451,9 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
         return msg.exec_() == QMessageBox.Yes
 
     def delete_action(self):
-        params = BorgDeleteThread.prepare(self.profile())
+        # Since this function modify the UI, we can't put the whole function in a JobQUeue.
+
+        params = BorgDeleteJob.prepare(self.profile())
         if not params['ok']:
             self._set_status(params['message'])
             return
@@ -461,12 +464,12 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                                        trans_late('ArchiveTab', "Are you sure you want to delete the archive?")):
                 return
             params['cmd'][-1] += f'::{self.archive_name}'
-
-            thread = BorgDeleteThread(params['cmd'], params, parent=self.app)
-            thread.updated.connect(self._set_status)
-            thread.result.connect(self.delete_result)
+            job = BorgDeleteJob(params['cmd'], params, self.profile().repo.id)
+            job.updated.connect(self._set_status)
+            job.result.connect(self.delete_result)
             self._toggle_all_buttons(False)
-            thread.start()
+            QApplication.instance().scheduler.jobs_manager.add_job(job)
+
         else:
             self._set_status(self.tr("No archive selected"))
 
@@ -490,14 +493,14 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
                 archive_name_newer = archive_cell_newer.text()
                 archive_name_older = archive_cell_older.text()
 
-                params = BorgDiffThread.prepare(profile, archive_name_older, archive_name_newer)
+                params = BorgDiffJob.prepare(profile, archive_name_older, archive_name_newer)
 
                 if params['ok']:
                     self._toggle_all_buttons(False)
-                    thread = BorgDiffThread(params['cmd'], params, parent=self.app)
-                    thread.updated.connect(self.mountErrors.setText)
-                    thread.result.connect(self.list_diff_result)
-                    thread.start()
+                    job = BorgDiffJob(params['cmd'], params, self.profile().repo.id)
+                    job.updated.connect(self.mountErrors.setText)
+                    job.result.connect(self.list_diff_result)
+                    QApplication.instance().scheduler.jobs_manager.add_job(job)
                 else:
                     self._set_status(params['message'])
 
@@ -522,8 +525,9 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
             window.show()
 
     def rename_action(self):
+
         profile = self.profile()
-        params = BorgRenameThread.prepare(profile)
+        params = BorgRenameJob.prepare(profile)
         if not params['ok']:
             self._set_status(params['message'])
             return
@@ -550,12 +554,11 @@ class ArchiveTab(ArchiveTabBase, ArchiveTabUI, BackupProfileMixin):
 
             params['cmd'][-1] += f'::{archive_name}'
             params['cmd'].append(new_name)
-
-            thread = BorgRenameThread(params['cmd'], params, parent=self)
-            thread.updated.connect(self._set_status)
-            thread.result.connect(self.rename_result)
+            job = BorgRenameJob(params['cmd'], params, self.profile().repo.id)
+            job.updated.connect(self._set_status)
+            job.result.connect(self.rename_result)
             self._toggle_all_buttons(False)
-            thread.start()
+            QApplication.instance().scheduler.jobs_manager.add_job(job)
         else:
             self._set_status(self.tr("No archive selected"))
 
