@@ -5,7 +5,6 @@ from PyQt5.QtCore import QPoint
 from PyQt5.QtGui import QKeySequence
 from PyQt5.QtWidgets import QShortcut, QMessageBox, QCheckBox, QMenu, QToolTip, QFileDialog
 
-from vorta.borg.borg_thread import BorgThread
 from vorta.models import BackupProfileModel, SettingsModel
 from vorta.utils import borg_compat, get_asset, is_system_tray_available, get_network_status_monitor
 from vorta.views.partials.loading_button import LoadingButton
@@ -19,7 +18,7 @@ from .profile_add_edit_dialog import AddProfileWindow, EditProfileWindow
 from .repo_tab import RepoTab
 from .schedule_tab import ScheduleTab
 from .source_tab import SourceTab
-
+from ..borg.job_scheduler import JobsManager
 
 uifile = get_asset('UI/mainwindow.ui')
 MainWindowUI, MainWindowBase = uic.loadUiType(uifile)
@@ -60,7 +59,6 @@ class MainWindow(MainWindowBase, MainWindowUI):
         self.repoTab.repo_changed.connect(self.archiveTab.populate_from_profile)
         self.repoTab.repo_changed.connect(self.scheduleTab.populate_from_profile)
         self.repoTab.repo_added.connect(self.archiveTab.list_action)
-        self.tabWidget.currentChanged.connect(self.scheduleTab._draw_next_scheduled_backup)
 
         self.createStartBtn.clicked.connect(self.app.create_backup_action)
         self.cancelButton.clicked.connect(self.app.backup_cancelled_event.emit)
@@ -94,7 +92,7 @@ class MainWindow(MainWindowBase, MainWindowUI):
             self.scheduleTab.toolBox.removeItem(1)
 
         # Connect to existing thread.
-        if BorgThread.is_running():
+        if JobsManager.is_worker_running():
             self.createStartBtn.setEnabled(False)
             self.createStartBtn.start()
             self.cancelButton.setEnabled(True)
@@ -245,8 +243,9 @@ class MainWindow(MainWindowBase, MainWindowUI):
         self.set_log('')
 
     def backup_finished_event(self):
-        self._toggle_buttons(create_enabled=True)
-        self.archiveTab._toggle_all_buttons(enabled=True)
+        if not JobsManager.is_worker_running():
+            self._toggle_buttons(create_enabled=True)
+            self.archiveTab._toggle_all_buttons(enabled=True)
         self.archiveTab.populate_from_profile()
         self.repoTab.init_repo_stats()
         self.scheduleTab.populate_logs()
