@@ -100,7 +100,7 @@ class SourceTab(SourceBase, SourceUI, BackupProfileMixin):
         self.sourceFilesWidget.item(index_row, SourceColumn.Type).setText(self.tr("Calculating..."))
         self.sourceFilesWidget.item(index_row, SourceColumn.Size).setText(self.tr("Calculating..."))
         self.sourceFilesWidget.item(index_row, SourceColumn.FilesCount).setText(self.tr("Calculating..."))
-        getDir = FilePathInfoAsync(path)
+        getDir = FilePathInfoAsync(path, self.profile().exclude_patterns)
         getDir.signal.connect(self.set_path_info)
         getDir.setObjectName(path)
         self.updateThreads.append(getDir)  # this is ugly, is there a better way to keep the thread object?
@@ -112,8 +112,10 @@ class SourceTab(SourceBase, SourceUI, BackupProfileMixin):
 
         index_row = self.sourceFilesWidget.rowCount()
         self.sourceFilesWidget.insertRow(index_row)
-        # Insert all items on current row
-        self.sourceFilesWidget.setItem(index_row, SourceColumn.Path, QTableWidgetItem(source.dir))
+        # Insert all items on current row, add tooltip containg the path name
+        new_item = QTableWidgetItem(source.dir)
+        new_item.setToolTip(source.dir)
+        self.sourceFilesWidget.setItem(index_row, SourceColumn.Path, new_item)
         self.sourceFilesWidget.setItem(index_row, SourceColumn.Type, QTableWidgetItem(""))
         self.sourceFilesWidget.setItem(index_row, SourceColumn.Size, SizeItem(""))
         self.sourceFilesWidget.setItem(index_row, SourceColumn.FilesCount, FilesCount(""))
